@@ -16,8 +16,8 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 57225 2008-12-10 02:59:48Z CJP $"
-__revision__ = "$Revision: 57225 $"
+__svnid__ = "$Id: Editra.py 57384 2008-12-17 04:28:54Z CJP $"
+__revision__ = "$Revision: 57384 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -614,7 +614,7 @@ def InitConfig():
         ed_glob.CONFIG['PROFILE_DIR'] += os.sep
     else:
         config_base = wx.StandardPaths.Get().GetUserDataDir()
-        ed_glob.CONFIG['PROFILE_DIR'] = util.ResolvConfigDir("profiles")
+        ed_glob.CONFIG['PROFILE_DIR'] = util.ResolvConfigDir(u"profiles")
 
     # Check for if config directory exists and if profile is from the current
     # running version of Editra.
@@ -696,20 +696,20 @@ def InitConfig():
 
     # Resolve resource locations
     ed_glob.CONFIG['CONFIG_DIR'] = util.ResolvConfigDir("")
-    ed_glob.CONFIG['SYSPIX_DIR'] = util.ResolvConfigDir("pixmaps", True)
-    ed_glob.CONFIG['PLUGIN_DIR'] = util.ResolvConfigDir("plugins")
-    ed_glob.CONFIG['THEME_DIR'] = util.ResolvConfigDir(os.path.join("pixmaps", "theme"))
-    ed_glob.CONFIG['LANG_DIR'] = util.ResolvConfigDir("locale", True)
-    ed_glob.CONFIG['STYLES_DIR'] = util.ResolvConfigDir("styles")
-    ed_glob.CONFIG['SYS_PLUGIN_DIR'] = util.ResolvConfigDir("plugins", True)
-    ed_glob.CONFIG['SYS_STYLES_DIR'] = util.ResolvConfigDir("styles", True)
-    ed_glob.CONFIG['TEST_DIR'] = util.ResolvConfigDir(os.path.join("tests", "syntax"), True)
+    ed_glob.CONFIG['SYSPIX_DIR'] = util.ResolvConfigDir(u"pixmaps", True)
+    ed_glob.CONFIG['PLUGIN_DIR'] = util.ResolvConfigDir(u"plugins")
+    ed_glob.CONFIG['THEME_DIR'] = util.ResolvConfigDir(os.path.join(u"pixmaps", u"theme"))
+    ed_glob.CONFIG['LANG_DIR'] = util.ResolvConfigDir(u"locale", True)
+    ed_glob.CONFIG['STYLES_DIR'] = util.ResolvConfigDir(u"styles")
+    ed_glob.CONFIG['SYS_PLUGIN_DIR'] = util.ResolvConfigDir(u"plugins", True)
+    ed_glob.CONFIG['SYS_STYLES_DIR'] = util.ResolvConfigDir(u"styles", True)
+    ed_glob.CONFIG['TEST_DIR'] = util.ResolvConfigDir(os.path.join(u"tests", u"syntax"), True)
 
     # Make sure all standard config directories are there
     for cfg in ["cache", "styles", "plugins", "profiles"]:
         if not util.HasConfigDir(cfg):
             util.MakeConfigDir(cfg)
-    ed_glob.CONFIG['CACHE_DIR'] = util.ResolvConfigDir("cache")
+    ed_glob.CONFIG['CACHE_DIR'] = util.ResolvConfigDir(u"cache")
 
     return profile_updated
 
@@ -824,8 +824,7 @@ def ProcessCommandLine():
         if opt in ['-h', '--help']:
             PrintHelp()
         elif opt in ['-v', '--version']:
-            print "%s - v%s - Developers Editor" % (ed_glob.PROG_NAME, \
-                                                    ed_glob.VERSION)
+            print ed_glob.VERSION
             os._exit(0)
         elif opt in ['-d', '--debug'] and '-D' not in opts:
             ed_glob.DEBUG = True
