@@ -20,8 +20,8 @@ makes the calls to the other support objects/functions in this library.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: autocomp.py 57307 2008-12-13 04:02:07Z CJP $"
-__revision__ = "$Revision: 57307 $"
+__cvsid__ = "$Id: autocomp.py 57407 2008-12-17 22:36:18Z CJP $"
+__revision__ = "$Revision: 57407 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -108,7 +108,14 @@ class AutoCompService(object):
             return self._completer.GetCallTipKeys()
         else:
             return list()
-        
+
+    def GetCallTipCancel(self):
+        """Get the list of key codes that should stop a calltip"""
+        if self._completer is not None:
+            return self._completer.GetCallTipCancel()
+        else:
+            return list()
+
     def IsCallTipEvent(self, evt):
         if self._completer:
             return self._completer.IsCallTipEvent(evt)
