@@ -9,11 +9,45 @@
 """
 Editra Control Library: ControlBox
 
+Sizer managed panel class with support for a toolbar like control that can be
+placed on the top/bottom of the main window area, multiple control bars are also
+possible.
+
+Class ControlBar:
+
+Toolbar like control with automatic item spacing and layout.
+
+Styles:
+  - CTRLBAR_STYLE_DEFAULT: Plain background
+  - CTRLBAR_STYLE_GRADIENT: Draw the bar with a vertical gradient.
+
+Class ControlBox:
+
+The ControlBox is a sizer managed panel that supports easy creation of windows
+that require a sandwich like layout.
+
++---------------------------------------+
+| ControlBar                            |
++---------------------------------------+
+|                                       |
+|                                       |
+|          MainWindow Area              |
+|                                       |
+|                                       |
+|                                       |
++---------------------------------------+
+| ControlBar                            |
++---------------------------------------+
+
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ctrlbox.py 57305 2008-12-13 03:34:22Z CJP $"
-__revision__ = "$Revision: 57305 $"
+__svnid__ = "$Id: ctrlbox.py 57382 2008-12-17 01:17:23Z CJP $"
+__revision__ = "$Revision: 57382 $"
+
+__all__ = ["ControlBar", "ControlBarEvent", "ControlBox",
+           "CTRLBAR_STYLE_DEFAULT", "CTRLBAR_STYLE_GRADIENT",
+           "EVT_CTRLBAR", "edEVT_CTRLBAR"]
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -79,6 +113,7 @@ class ControlBox(wx.PyPanel):
 
     def GetControlBar(self, pos=wx.TOP):
         """Get the L{ControlBar} used by this window
+        @param pos: wx.TOP or wx.BOTTOM
         @return: ControlBar or None
 
         """
@@ -96,6 +131,36 @@ class ControlBox(wx.PyPanel):
         """
         return self._main
 
+    def ReplaceControlBar(self, ctrlbar, pos=wx.TOP):
+        """Replace the L{ControlBar} at the given position
+        with the given ctrlbar and return the bar that was
+        replaced or None.
+        @param ctrlbar: L{ControlBar}
+        @keyword pos: Postion
+        @return: L{ControlBar} or None
+
+        """
+        tbar = self.GetControlBar(pos)
+        rbar = None
+        if pos == wx.TOP:
+            if tbar is None:
+                self._sizer.Insert(0, ctrlbar, 0, wx.EXPAND)
+            else:
+                self._sizer.Replace(self._topb, ctrlbar)
+                rbar = self._topb
+
+            self._topb = ctrlbar
+        else:
+            if tbar is None:
+                self._sizer.Add(ctrlbar, 0, wx.EXPAND)
+            else:
+                self._sizer.Replace(self._botb, ctrlbar)
+                rbar = self._botb
+
+            self._botb = ctrlbar
+
+        return rbar
+
     def SetControlBar(self, ctrlbar, pos=wx.TOP):
         """Set the ControlBar used by this ControlBox
         @param ctrlbar: L{ControlBar}
