@@ -43,33 +43,39 @@ a solid color it may cause the control to loose its transparent appearance.
 Other attributes can be configured after the control has been created. The
 settings that are currently available are as follows:
 
-SetBitmap: Change/Add the bitmap at any time and the control will resize and
-           refresh to display it.
-SetLabelColor: Explicitly set text colors
-SetMenu: Set the button to have a popupmenu. When a menu is set a small drop
-         arrow will be drawn on the button that can then be clicked to show
-         a menu.
-SetPressColor: Use a custom highlight color
+  - SetBitmap: Change/Add the bitmap at any time and the control will resize and
+               refresh to display it.
+  - SetLabelColor: Explicitly set text colors
+  - SetMenu: Set the button to have a popupmenu. When a menu is set a small drop
+             arrow will be drawn on the button that can then be clicked to show
+             a menu.
+  - SetPressColor: Use a custom highlight color
 
 
 Overridden Methods Inherited from PyControl:
 
-SetFont: Changing the font is one way to set the size of the button, by default
-         the control will inherit its font from its parent.
+  - SetFont: Changing the font is one way to set the size of the button, by
+             default the control will inherit its font from its parent.
 
-SetWindowVariant: Setting the window variant will cause the control to resize to
-                  the corresponding variant size. However if the button is using
-                  a bitmap the bitmap will remain unchanged and only the font
-                  will be adjusted.
+  - SetWindowVariant: Setting the window variant will cause the control to
+                      resize to the corresponding variant size. However if the
+                      button is using a bitmap the bitmap will remain unchanged
+                      and only the font will be adjusted.
 
 Requirements:
-    This module requires python2.4 or higher and wxPython2.8 or higher
+  - python2.4 or higher
+  - wxPython2.8 or higher
 
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: platebtn.py 51429 2008-01-29 07:44:37Z CJP $"
-__revision__ = "$Revision: 51429 $"
+__svnid__ = "$Id: platebtn.py 57345 2008-12-14 23:47:52Z CJP $"
+__revision__ = "$Revision: 57345 $"
+
+__all__ = ["PlateButton", "AdjustAlpha", "AdjustColor", "GetHighlightColor",
+           "PLATE_NORMAL", "PLATE_PRESSED", "PLATE_HIGHLIGHT", 
+           "PB_STYLE_DEFAULT", "PB_STYLE_GRADIENT", "PB_STYLE_SQUARE",
+           "PB_STYLE_NOBG" ]
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -433,10 +439,7 @@ class PlateButton(wx.PyControl):
         p_attr = self.GetParent().GetDefaultAttributes()
         my_def = bkgrd == my_attr.colBg
         p_def = self.GetParent().GetBackgroundColour() == p_attr.colBg
-        if my_def and p_def and wx.Platform == '__WXMSW__':
-            if self.DoEraseBackground(dc):
-                brush = wx.TRANSPARENT_BRUSH
-        elif my_def and not p_def:
+        if my_def and not p_def:
             bkgrd = self.GetParent().GetBackgroundColour()
             brush = wx.Brush(bkgrd, wx.SOLID)
         return brush
