@@ -14,8 +14,8 @@ access point for all common variables in the project.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_glob.py 57303 2008-12-13 02:07:58Z CJP $"
-__revision__ = "$Revision: 57303 $"
+__svnid__ = "$Id: ed_glob.py 57415 2008-12-18 05:02:07Z CJP $"
+__revision__ = "$Revision: 57415 $"
 
 __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE', 'ID_SAVEAS', 'ID_SAVEALL',
@@ -40,7 +40,7 @@ __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_USE_SOFTTABS', 'ID_DUP_LINE', 'ID_TRANSLATE',
             'I18N_PAGE', 'ID_GOTO_MBRACE', 'ID_HLCARET_LINE', 'ID_SHOW_SB',
             'ID_REVERT_FILE', 'ID_RELOAD_ENC', 'ID_DOCPROP', 'ID_PASTE_AFTER',
-            'ID_COLUMN_MODE']
+            'ID_COLUMN_MODE', 'ID_PANELIST', 'ID_NEW_WINDOW']
 
 #---- Project Info ----#
 # The project info was moved to another module so it could be accessed
@@ -172,6 +172,7 @@ ID_INDENT_GUIDES = wx.NewId()
 ID_SHOW_SB       = wx.NewId()
 ID_VIEW_TOOL     = wx.NewId()
 ID_SHELF         = wx.NewId()
+ID_PANELIST      = wx.NewId()
 ID_GOTO_LINE     = wx.NewId()
 ID_GOTO_MBRACE   = wx.NewId()
 ID_NEXT_MARK     = wx.ID_FORWARD
