@@ -15,8 +15,8 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 57303 2008-12-13 02:07:58Z CJP $"
-__revision__ = "$Revision: 57303 $"
+__svnid__ = "$Id: ed_main.py 57415 2008-12-18 05:02:07Z CJP $"
+__revision__ = "$Revision: 57415 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -45,6 +45,7 @@ import plugin
 import perspective as viewmgr
 import iface
 import eclib.encdlg as encdlg
+import eclib.auinavi as auinavi
 
 # Function Aliases
 _ = wx.GetTranslation
@@ -101,10 +102,14 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                           Name("EditPane").Center().Layer(1).Dockable(False). \
                           CloseButton(False).MaximizeButton(False). \
                           CaptionVisible(False))
+        self._mpane.InitCommandBar() # <- required due to nb dependancies...
 
         #---- Command Bar ----#
         self._mpane.HideCommandBar()
 
+        #---- Pane Navigator ----#
+        self._paneNavi = None
+
         #---- Setup Toolbar ----#
         self.SetToolBar(ed_toolbar.EdToolBar(self))
         self.GetToolBar().Show(_PGET('TOOLBAR'))
@@ -163,6 +168,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                        (ID_GOTO_MBRACE, self.DispatchToControl),
                                        (ID_SHOW_SB, self.OnShowStatusBar),
                                        (ID_VIEW_TOOL, self.OnViewTb),
+                                       (ID_PANELIST, self.OnPaneList),
 
                                        # Format Menu
                                        (ID_FONT, self.OnFont),
@@ -404,7 +410,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
     def GetCommandbar(self):
         """Get this windows command bar
-        @return: ed_cmdbar.CommandBar
+        @return: ed_cmdbar.CommandBarBase
 
         """
         return self._mpane.GetControlBar(wx.BOTTOM)
@@ -995,6 +1001,35 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         else:
             evt.Skip()
 
+    def OnPaneList(self, evt):
+        """Navigates through panes
+        @param event: CommandEvent instance
+
+        """
+        if evt.GetId() == ID_PANELIST:
+            if self._paneNavi is not None:
+                return
+
+            bmp = wx.ArtProvider.GetBitmap(str(ID_NEW_WINDOW), wx.ART_MENU)
+            self._paneNavi = auinavi.AuiPaneNavigator(self, self._mgr, bmp,
+                                                      _("Aui Pane Navigator"))
+            self._paneNavi.SetReturnCode(wx.ID_OK)
+            self._paneNavi.ShowModal()
+
+            sel = self._paneNavi.GetSelection()
+            self._paneNavi.Destroy()
+            self._paneNavi = None
+
+            if isinstance(sel, basestring):
+                paneInfo = self._mgr.GetPane(sel)
+                if paneInfo.IsOk():
+                    if not paneInfo.IsShown():
+                        paneInfo.Show()
+                        self._mgr.Update()
+                    paneInfo.window.SetFocus()
+        else:
+            evt.Skip()
+
     # Menu Update Handlers
     def OnUpdateFileUI(self, evt):
         """Update filemenu items
