@@ -14,8 +14,8 @@ for managing keybindings and profiles is also provided by this module.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_menu.py 57303 2008-12-13 02:07:58Z CJP $"
-__revision__ = "$Revision: 57303 $"
+__svnid__ = "$Id: ed_menu.py 57422 2008-12-18 17:44:54Z CJP $"
+__revision__ = "$Revision: 57422 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -246,7 +246,7 @@ class KeyBinder(object):
         @return: list of strings
 
         """
-        recs = util.GetResourceFiles('cache', trim=True, get_all=False,
+        recs = util.GetResourceFiles(u'cache', trim=True, get_all=False,
                                      suffix='.ekeys', title=False)
         if recs == -1:
             recs = list()
@@ -662,6 +662,9 @@ class EdMenuBar(wx.MenuBar):
                         _("Show Whitespace Markers"), wx.ITEM_CHECK)
         viewmenu.AppendSubMenu(self._menus['viewedit'], _("Editor"), \
                                _("Toggle Editor View Options"))
+        viewmenu.Append(ed_glob.ID_PANELIST, _("Pane Navigator") + \
+                        EdMenuBar.keybinder.GetBinding(ed_glob.ID_PANELIST),
+                        _("View pane selection list"))
         viewmenu.AppendSeparator()
         viewmenu.Append(ed_glob.ID_GOTO_LINE, _("&Goto Line") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_GOTO_LINE),
@@ -986,7 +989,7 @@ _DEFAULT_BINDING = { # File Menu
                      ed_glob.ID_PASTE : ("Ctrl", "V"),
                      ed_glob.ID_PASTE_AFTER : ("Ctrl", "Shift", "V"),
                      ed_glob.ID_SELECTALL : ("Ctrl", "A"),
-                     ed_glob.ID_COLUMN_MODE : ("Ctrl", "|"),
+                     ed_glob.ID_COLUMN_MODE : ("Ctrl", "Shift", "|"),
                      ed_glob.ID_LINE_AFTER : ("Ctrl", "L"),
                      ed_glob.ID_LINE_BEFORE : ("Ctrl", "Shift", "L"),
                      ed_glob.ID_CUT_LINE : ("Ctrl", "D"),
@@ -1010,6 +1013,7 @@ _DEFAULT_BINDING = { # File Menu
                      ed_glob.ID_NEXT_MARK : ("Alt", "Right"), # Win/Linux
                      ed_glob.ID_PRE_MARK : ("Alt", "Left"), # Win/Linux
                      ed_glob.ID_SHOW_SHELF : ("Ctrl", "Alt", "S"),
+                     ed_glob.ID_PANELIST : ("Alt", "1"), # Win/Linux
 
                      # Format Menu
                      ed_glob.ID_COMMENT : ("Ctrl", "1"),
@@ -1032,6 +1036,7 @@ if wx.Platform == '__WXMAC__':
     _DEFAULT_BINDING[ed_glob.ID_FIND_PREVIOUS] = ("Ctrl", "Shift", "G")
     _DEFAULT_BINDING[ed_glob.ID_FIND_NEXT] = ("Ctrl", "G")
     _DEFAULT_BINDING[ed_glob.ID_GOTO_LINE] = ("Ctrl", "Shift", "E")
+    _DEFAULT_BINDING[ed_glob.ID_PANELIST] = ("Alt", "Tab")
 elif wx.Platform == '__WXMSW__':
      # FIXME: On Windows if Tab is bound to a menu item it is no longer
      #        usable elsewhere such as in the stc control. On Mac/Gtk there
