@@ -13,8 +13,8 @@ This class implements Editra's main notebook control.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 57300 2008-12-13 00:18:29Z CJP $"
-__revision__ = "$Revision: 57300 $"
+__svnid__ = "$Id: ed_pages.py 57362 2008-12-15 20:57:12Z CJP $"
+__revision__ = "$Revision: 57362 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -142,6 +142,12 @@ class EdPages(FNB.FlatNotebook):
             msg = _("The correct encoding of '%s' could not be determined.\n\n"
                     "Choose an encoding and select Ok to open the file with the chosen encoding.\n"
                     "Click Cancel to abort opening the file") % fname
+
+            # On some systems it seems that default encoding ends up being
+            # None so default to utf-8 for choices.
+            if enc is None:
+                enc = 'utf_8'
+
             dlg = encdlg.EncodingDialog(self, msg=msg,
                                         title=_("Choose an Encoding"),
                                         default=enc)
