@@ -16,8 +16,8 @@ highlight text in a StyledTextCtrl.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_search.py 57224 2008-12-10 02:38:27Z CJP $"
-__revision__ = "$Revision: 57224 $"
+__svnid__ = "$Id: ed_search.py 57416 2008-12-18 05:30:38Z CJP $"
+__revision__ = "$Revision: 57416 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -179,8 +179,10 @@ class SearchController:
 
         # Find next from menu event or called internally by replace
         if findnext or evt.GetEventType() == wx.wxEVT_COMMAND_MENU_SELECTED:
+
+            # Adjust flags
             flags = data.GetFlags()
-            if evt.GetId() == ed_glob.ID_FIND_PREVIOUS:
+            if not findnext and evt.GetId() == ed_glob.ID_FIND_PREVIOUS:
                 flags |= finddlg.AFR_UP
 
             evt = finddlg.FindEvent(finddlg.edEVT_FIND_NEXT,
@@ -351,7 +353,10 @@ class SearchController:
         self._stc().ReplaceSelection(replacestring)
 
         # Go to the next match
-        self.OnFind(None, True)
+        # Fake event object for on Find Handler
+        tevt = finddlg.FindEvent(finddlg.edEVT_FIND_NEXT,
+                                 ed_glob.ID_FIND_PREVIOUS)
+        self.OnFind(tevt, True)
 
     def OnReplaceAll(self, evt):
         """Replace all instance of the search string with the given
@@ -565,7 +570,7 @@ class SearchEngine:
         if self._regex is None:
             return list()
 
-        matches = [match for match in re.finditer(self._regex, self._pool)]
+        matches = [match for match in self._regex.finditer(self._pool)]
         return matches
 
     def FindAllLines(self):
@@ -577,12 +582,8 @@ class SearchEngine:
         if self._regex is None:
             return rlist
 
-        flag = 0
-        if not self._matchcase:
-            flag = re.IGNORECASE
-
         for lnum, line in enumerate(StringIO(self._pool)):
-            if self._regex.search(line, flag) is not None:
+            if self._regex.search(line) is not None:
                 rlist.append(FormatResult(_("Untitled"), lnum, line))
 
         return rlist
@@ -615,7 +616,7 @@ class SearchEngine:
             return None
 
         if spos+1 < len(self._pool):
-            matches = [match for match in re.finditer(self._regex, self._pool[:spos])]
+            matches = [match for match in self._regex.finditer(self._pool[:spos])]
             if len(matches):
                 lmatch = matches[-1]
                 return (lmatch.start(), lmatch.end())
@@ -693,7 +694,7 @@ class SearchEngine:
                 for fname in os.listdir(directory) if not fname.startswith('.')]
 
         # Filter out files that don't match the current filter(s)
-        if self._filters is not None:
+        if self._filters is not None and len(self._filters):
             filtered = list()
             for fname in paths:
                 if os.path.isdir(fname):
@@ -736,12 +737,8 @@ class SearchEngine:
                 # Special token to signify start of a search
                 yield (None, fname)
 
-            flag = 0
-            if not self._matchcase:
-                flag = re.IGNORECASE
-
             for lnum, line in enumerate(fobj):
-                if self._regex.search(line, flag) is not None:
+                if self._regex.search(line) is not None:
                     yield FormatResult(fname, lnum, line)
             fobj.close()
         return
@@ -849,7 +846,7 @@ class EdSearchCtrl(wx.SearchCtrl):
         # Attributes
         self._parent     = parent
         # TEMP HACK
-        self.FindService = self.GetTopLevelParent().nb._searchctrl
+        self.FindService = self.GetTopLevelParent().GetNotebook()._searchctrl
         self._flags      = 0
         self._recent     = list()        # The History List
         self._last       = None
@@ -1023,6 +1020,12 @@ class EdSearchCtrl(wx.SearchCtrl):
             return bool(finddlg.AFR_WHOLEWORD & data.GetFlags())
         return False
 
+    def SetFocus(self):
+        """Set the focus and select the text"""
+        super(EdSearchCtrl, self).SetFocus()
+        self.AutoSetQuery()
+        self.SelectAll()
+
     def SetHistory(self, hist_list):
         """Populates the history list from a list of
         string values.
@@ -1062,6 +1065,7 @@ class EdSearchCtrl(wx.SearchCtrl):
             # TODO change to more safely determine the context
             # Currently control is only used in command bar
             self.GetParent().Hide()
+            evt.Skip()
             return
         elif e_key == wx.WXK_SHIFT:
             self.ClearSearchFlag(finddlg.AFR_UP)
