@@ -18,8 +18,8 @@ specific options such as commenting code.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 57306 2008-12-13 03:52:25Z CJP $"
-__revision__ = "$Revision: 57306 $"
+__svnid__ = "$Id: ed_stc.py 57407 2008-12-17 22:36:18Z CJP $"
+__revision__ = "$Revision: 57407 $"
 
 #-------------------------------------------------------------------------#
 # Imports
@@ -167,6 +167,12 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         # Context Menu Events
         self.Bind(wx.EVT_CONTEXT_MENU, lambda evt: self.PopupMenu(self._menu))
+        
+        # Need to relay the menu events from the context menu to the top level
+        # window to be handled on gtk. Other platforms don't require this.
+        if wx.Platform == '__WXGTK__':
+            self.Bind(wx.EVT_MENU,
+                      lambda evt: wx.PostEvent(self.GetTopLevelParent(), evt))
 
        #---- End Init ----#
 
@@ -768,24 +774,29 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             # The key handler handled this keypress, we don't need to insert
             # the character into the buffer.
             pass
+
         elif not self._config['autocomp'] or \
-             self.IsString(cpos) or \
-             self.IsComment(cpos):
+             self.IsString(cpos) or self.IsComment(cpos):
             evt.Skip()
             return
+
         elif key_code in self._code['compsvc'].GetAutoCompKeys():
             if self.AutoCompActive():
                 self.AutoCompCancel()
+            if self.CallTipActive():
+                self.CallTipCancel()
             command = self.GetCommandStr() + unichr(key_code)
             self.AddText(unichr(key_code))
             if self._config['autocomp']:
                 self.ShowAutoCompOpt(command)
+
         elif self._code['compsvc'].IsAutoCompEvent(evt):
             if self.AutoCompActive():
                 self.AutoCompCancel()
             command = self.GetCommandStr()
             if self._config['autocomp']:
                 self.ShowAutoCompOpt(command)
+
         elif key_code in self._code['compsvc'].GetCallTipKeys():
             if self.AutoCompActive():
                 self.AutoCompCancel()
@@ -793,12 +804,18 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             self.AddText(unichr(key_code))
             if self._config['autocomp']:
                 self.ShowCallTip(command)
+
         elif self._code['compsvc'].IsCallTipEvent(evt):
             if self.AutoCompActive():
                 self.AutoCompCancel()
             command = self.GetCommandStr()
             if self._config['autocomp']:
                 self.ShowCallTip(command[:command.rfind('(')])
+
+        elif key_code in self._code['compsvc'].GetCallTipCancel():
+            evt.Skip()
+            if self.CallTipActive():
+                self.CallTipCancel()
         else:
             evt.Skip()
         return
@@ -877,15 +894,16 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """Gets the command string to the left of the autocomp
         activation character.
         @return: the command string to the left of the autocomp char
+        @todo: fillups are currently disabled. See note in Configure.
 
         """
         curr_pos = self.GetCurrentPos()
         start = curr_pos - 1
         col = self.GetColumn(curr_pos)
-        cmd_lmt = list(self._code['compsvc'].GetAutoCompStops() + \
-                       self._code['compsvc'].GetAutoCompFillups())
+        cmd_lmt = list(self._code['compsvc'].GetAutoCompStops())# + \
+                       #self._code['compsvc'].GetAutoCompFillups())
         for key in self._code['compsvc'].GetAutoCompKeys():
-            kval = chr(key)
+            kval = unichr(key)
             if kval in cmd_lmt:
                 cmd_lmt.remove(kval)
 
@@ -2135,7 +2153,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.Refresh()
 
     def UpdateBaseStyles(self):
+        """Update the controls basic styles"""
         ed_style.StyleMgr.UpdateBaseStyles(self)
+
+        # Set control specific styles
         sback = self.GetItemByName('select_style')
         if not sback.IsNull():
             sback = sback.GetBack()
