@@ -19,8 +19,8 @@ Intefaces:
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: iface.py 56539 2008-10-28 02:44:26Z CJP $"
-__revision__ = "$Revision: 56539 $"
+__svnid__ = "$Id: iface.py 57127 2008-12-05 16:27:18Z CJP $"
+__revision__ = "$Revision: 57127 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -270,7 +270,8 @@ class Shelf(plugin.Plugin):
                                              FNB.FNB_BACKGROUND_GRADIENT |
                                              FNB.FNB_NODRAG |
                                              FNB.FNB_BOTTOM |
-                                             FNB.FNB_NO_X_BUTTON)
+                                             FNB.FNB_NO_X_BUTTON |
+                                             FNB.FNB_MOUSE_MIDDLE_CLOSES_TABS)
         self._shelf.SetImageList(self._imglst)
         mgr.AddPane(self._shelf, wx.aui.AuiPaneInfo().Name(Shelf.SHELF_NAME).\
                             Caption("Shelf").Bottom().Layer(0).\
