@@ -16,8 +16,8 @@ and setting of the program by setting values in the Profile.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: prefdlg.py 57121 2008-12-05 04:14:55Z CJP $"
-__revision__ = "$Revision: 57121 $"
+__svnid__ = "$Id: prefdlg.py 57420 2008-12-18 16:37:26Z CJP $"
+__revision__ = "$Revision: 57420 $"
 
 #----------------------------------------------------------------------------#
 # Dependancies
@@ -40,6 +40,7 @@ import util
 import syntax.syntax as syntax
 import ed_msg
 import eclib.elistmix as elistmix
+import eclib.ecpickers as ecpickers
 
 #----------------------------------------------------------------------------#
 # Globals
@@ -50,20 +51,20 @@ ID_UPDATE_MSG   = wx.NewId()
 _ = wx.GetTranslation
 #----------------------------------------------------------------------------#
 # Class Globals
-from extern.embeddedimage import PyEmbeddedImage
+#from extern.embeddedimage import PyEmbeddedImage
 
-ButtonBackground = PyEmbeddedImage(
-    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAfhJ"
-    "REFUWIXtlz9uGkEUh7/ZWbDdEAWH0ltRYCKRigNQxhFS3EUuUjlGspQLODfIAVxEkVPFzgmc"
-    "LhegCoolupWQ6GIcWIvE7DwmBX9iwGBiMG74SVvM6M37ffPeaEarGFQceJbJZA611inmKBEp"
-    "l0qlfeA7UOvNq2sxu6lUKpfNZne2nm+x/mR9nv6c/zzn9OspxWLxuFwuvwakB+BEIpE3hb3C"
-    "+2QyGfM8b67Gw6pUKhy8O/jQbDb3AVFAbvvl9rd8Pn+vxtdVrVY5+nR07Pv+W3djw9vzPI8g"
-    "uATsQgBisUdsbqZ3fN//6EZc91UikSAIGrcutNZirUUphVLq1vhJeppOc3b249A1xlD/VZ9s"
-    "3K2MYjbTkbxtm3KNGBpT7H58FrgrlxGDKyI0GsHdAWaQiNBpQX2wBRM3ZKcJmry0J2MMrhjh"
-    "MnigChjBDY2hVrtAaz3zyZ5W1lpEhNAYFN3KxB/HiUai/SCtNdHoylwMW60rROTfOGxRu+g8"
-    "B32AYWmtWYmuDswppVhbXcNxnJH4tm0ThiHGhNihjFetPwMAAznHAYyTqyNA50IaosNaS7t9"
-    "s9E4/TfAvDVayyXAEmAJsARYAixWLxzgywMC/AbI0XmQFv19pvMvigMUgPoCzevA7nA5CgsE"
-    "KNzUD6fbjpN7ND7pevQP/18X4iAGbqux9wAAAABJRU5ErkJggg==")
+#ButtonBackground = PyEmbeddedImage(
+#    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAfhJ"
+#    "REFUWIXtlz9uGkEUh7/ZWbDdEAWH0ltRYCKRigNQxhFS3EUuUjlGspQLODfIAVxEkVPFzgmc"
+#    "LhegCoolupWQ6GIcWIvE7DwmBX9iwGBiMG74SVvM6M37ffPeaEarGFQceJbJZA611inmKBEp"
+#    "l0qlfeA7UOvNq2sxu6lUKpfNZne2nm+x/mR9nv6c/zzn9OspxWLxuFwuvwakB+BEIpE3hb3C"
+#    "+2QyGfM8b67Gw6pUKhy8O/jQbDb3AVFAbvvl9rd8Pn+vxtdVrVY5+nR07Pv+W3djw9vzPI8g"
+#    "uATsQgBisUdsbqZ3fN//6EZc91UikSAIGrcutNZirUUphVLq1vhJeppOc3b249A1xlD/VZ9s"
+#    "3K2MYjbTkbxtm3KNGBpT7H58FrgrlxGDKyI0GsHdAWaQiNBpQX2wBRM3ZKcJmry0J2MMrhjh"
+#    "MnigChjBDY2hVrtAaz3zyZ5W1lpEhNAYFN3KxB/HiUai/SCtNdHoylwMW60rROTfOGxRu+g8"
+#    "B32AYWmtWYmuDswppVhbXcNxnJH4tm0ThiHGhNihjFetPwMAAznHAYyTqyNA50IaosNaS7t9"
+#    "s9E4/TfAvDVayyXAEmAJsARYAixWLxzgywMC/AbI0XmQFv19pvMvigMUgPoCzevA7nA5CgsE"
+#    "KNzUD6fbjpN7ND7pevQP/18X4iAGbqux9wAAAABJRU5ErkJggg==")
 
 def MakeThemeTool(tool_id):
     """Makes a themed bitmap for the tool book of the pref dialog.
@@ -72,21 +73,10 @@ def MakeThemeTool(tool_id):
 
     """
     osize = Profile_Get('ICON_SZ', 'size_tuple', (24, 24))
-    Profile_Set('ICON_SZ', (24, 24))
+    Profile_Set('ICON_SZ', (32, 32))
     over = wx.ArtProvider.GetBitmap(str(tool_id), wx.ART_TOOLBAR)
     Profile_Set('ICON_SZ', osize)
-    mdc = wx.MemoryDC(ButtonBackground.GetBitmap())
-    if over.IsOk():
-        # Create overlay
-        if over.GetSize() != (24, 24):
-            over = over.ConvertToImage()
-            over.Rescale(24, 24, wx.IMAGE_QUALITY_HIGH)
-            over = over.ConvertToBitmap()
-
-        # Draw overlay onto button
-        mdc.SetBrush(wx.TRANSPARENT_BRUSH)
-        mdc.DrawBitmap(over, 4, 4, True)
-    return mdc.GetAsBitmap()
+    return over
 
 #----------------------------------------------------------------------------#
 
@@ -508,7 +498,7 @@ class DocGenPanel(wx.Panel):
         # Event Handlers
         self.Bind(wx.EVT_CHECKBOX, self.OnUpdateEditor)
         self.Bind(wx.EVT_CHOICE, self.OnUpdateEditor)
-        self.Bind(ed_event.EVT_NOTIFY, self.OnFontChange)
+        self.Bind(ecpickers.EVT_FONT_CHANGED, self.OnFontChange)
 
     def __DoLayout(self):
         """Layout the controls
@@ -568,12 +558,12 @@ class DocGenPanel(wx.Panel):
         fnt = Profile_Get('FONT1', 'font', wx.Font(10, wx.FONTFAMILY_MODERN,
                                                    wx.FONTSTYLE_NORMAL,
                                                    wx.FONTWEIGHT_NORMAL))
-        fpick = PyFontPicker(self, DocGenPanel.ID_FONT_PICKER, fnt)
+        fpick = ecpickers.PyFontPicker(self, DocGenPanel.ID_FONT_PICKER, fnt)
         fpick.SetToolTipString(_("Sets the main/default font of the document"))
         fnt = Profile_Get('FONT2', 'font', wx.Font(10, wx.FONTFAMILY_SWISS,
                                                    wx.FONTSTYLE_NORMAL,
                                                    wx.FONTWEIGHT_NORMAL))
-        fpick2 = PyFontPicker(self, DocGenPanel.ID_FONT_PICKER2, fnt)
+        fpick2 = ecpickers.PyFontPicker(self, DocGenPanel.ID_FONT_PICKER2, fnt)
         fpick2.SetToolTipString(_("Sets a secondary font used for special "
                                   "regions when syntax highlighting is in use"))
 
@@ -609,7 +599,7 @@ class DocGenPanel(wx.Panel):
 
     @staticmethod
     def OnFontChange(evt):
-        """Handles L{ed_event.EVT_NOTIFY} from the font controls"""
+        """Handles L{ecpickers.EVT_FONT_CHANGED} from the font controls"""
         e_id = evt.GetId()
         if e_id in [DocGenPanel.ID_FONT_PICKER, DocGenPanel.ID_FONT_PICKER2]:
             font = evt.GetValue()
@@ -965,7 +955,7 @@ class AppearancePanel(wx.Panel):
 
         # Font
         fnt = Profile_Get('FONT3', 'font', wx.NORMAL_FONT)
-        fpick = PyFontPicker(self, wx.ID_ANY, fnt)
+        fpick = ecpickers.PyFontPicker(self, wx.ID_ANY, fnt)
         fpick.SetToolTipString(_("Main display font for various UI components"))
 
         # Misc
@@ -1391,7 +1381,7 @@ KEYS = ['', 'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M',
         'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z',
         '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', '-', '+', '/', ',',
         '.', '[', ']', '{', '}', ':', 'Left', 'Right', 'Down', 'Up', 'Home',
-        'End', 'Tab']
+        'End', 'Enter', 'Tab']
 KEYS.extend(["F" + str(x) for x in range(1, 13)])
 
 if wx.Platform == '__WXMSW__':
@@ -1894,98 +1884,6 @@ class ExChoice(wx.Choice):
             val.lower()
         return val
 
-class PyFontPicker(wx.Panel):
-    """A slightly enhanced wx.FontPickerCtrl that displays the choosen font in
-    the text control using the choosen font as well as the font's size using
-    nicer formatting.
-
-    """
-    def __init__(self, parent, id_=wx.ID_ANY, default=wx.NullFont):
-        """Initializes the PyFontPicker
-        @param default: The font to initialize as selected in the control
-
-        """
-        wx.Panel.__init__(self, parent, id_, style=wx.NO_BORDER)
-
-        # Attributes
-        if default == wx.NullFont:
-            self._font = wx.SystemSettings_GetFont(wx.SYS_SYSTEM_FONT)
-        else:
-            self._font = default
-        self._text = wx.TextCtrl(self, style=wx.TE_CENTER | wx.TE_READONLY)
-        self._text.SetFont(default)
-        self._text.SetValue(u"%s - %dpt" % (self._font.GetFaceName(), \
-                                            self._font.GetPointSize()))
-        self._button = wx.Button(self, label=_("Set Font") + u'...')
-
-        # Layout
-        sizer = wx.BoxSizer(wx.HORIZONTAL)
-        sizer.AddMany([(self._text, 1, wx.ALIGN_CENTER_VERTICAL), ((5, 5), 0),
-                       (self._button, 0, wx.ALIGN_CENTER_VERTICAL)])
-        self.SetSizer(sizer)
-        self.SetAutoLayout(True)
-
-        # Event Handlers
-        self.Bind(wx.EVT_BUTTON, lambda evt: self.ShowFontDlg(), self._button)
-        self.Bind(wx.EVT_FONTPICKER_CHANGED, self.OnChange)
-
-    def GetFontValue(self):
-        """Gets the currently choosen font
-        @return: wx.Font
-
-        """
-        return self._font
-
-    def GetTextCtrl(self):
-        """Gets the widgets text control
-        @return: wx.TextCtrl
-
-        """
-        return self._text
-
-    def OnChange(self, evt):
-        """Updates the text control using our custom stylings after
-        the font is changed.
-        @param evt: The event that called this handler
-
-        """
-        font = evt.GetFont()
-        if font.IsNull():
-            return
-        self._font = font
-        self._text.Clear()
-        self._text.SetFont(self._font)
-        self._text.SetValue(u"%s - %dpt" % (font.GetFaceName(), \
-                                            font.GetPointSize()))
-        evt = ed_event.NotificationEvent(ed_event.edEVT_NOTIFY,
-                                         self.GetId(), self._font, self)
-        wx.PostEvent(self.GetParent(), evt)
-
-    def SetButtonLabel(self, label):
-        """Sets the buttons label"""
-        self._button.SetLabel(label)
-        self._button.Refresh()
-
-    def SetToolTipString(self, tip):
-        """Sets the tooltip of the window
-        @param tip: string
-
-        """
-        self._text.SetToolTipString(tip)
-        self._button.SetToolTipString(tip)
-        wx.Panel.SetToolTipString(self, tip)
-
-    def ShowFontDlg(self):
-        """Opens the FontDialog and processes the result"""
-        fdata = wx.FontData()
-        fdata.SetInitialFont(self._font)
-        fdlg = wx.FontDialog(self.GetParent(), fdata)
-        fdlg.ShowModal()
-        fdata = fdlg.GetFontData()
-        fdlg.Destroy()
-        wx.PostEvent(self, wx.FontPickerEvent(self, self.GetId(),
-                                              fdata.GetChosenFont()))
-
 #-----------------------------------------------------------------------------#
 # Utility Functions
 
