@@ -20,8 +20,8 @@ happen during run time.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: profiler.py 56855 2008-11-19 21:23:23Z CJP $"
-__revision__ = "$Revision: 56855 $"
+__svnid__ = "$Id: profiler.py 57296 2008-12-12 22:33:02Z CJP $"
+__revision__ = "$Revision: 57296 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -78,6 +78,7 @@ _DEFAULTS = {
            'SAVE_POS'   : True,             # Remember Carat positions
            'SAVE_SESSION' : False,          # Load previous session on startup
            'SEARCH_LOC' : list(),           # Recent Search Locations
+           'SEARCH_FILTER' : '',            # Last used search filter
            'SESSION_KEY' : '',              # Ipc Session Server Key
            'SET_WPOS'   : True,             # Remember window position
            'SET_WSIZE'  : True,             # Remember mainwindow size on exit
@@ -141,7 +142,7 @@ class Profile(dict):
         @type item: string
 
         """
-        if self.has_key(item):
+        if item in self:
             del self[item]
         else:
             pass
@@ -155,7 +156,7 @@ class Profile(dict):
                           not in profile.
 
         """
-        if self.has_key(index):
+        if index in self:
             val = self.__getitem__(index)
         else:
             return default
@@ -247,13 +248,18 @@ class Profile(dict):
         """
         if update is None:
             for key, val in _DEFAULTS.iteritems():
-                if not self.has_key(key):
+                if key not in self:
                     self.Set(key, val)
         else:
             self.update(update)
 
     #---- End Public Members ----#
 
+#-----------------------------------------------------------------------------#
+# Singleton reference instance
+
+TheProfile = Profile()
+
 #-----------------------------------------------------------------------------#
 # Profile convenience functions
 def Profile_Del(item):
@@ -261,7 +267,7 @@ def Profile_Del(item):
     @param item: items key name
 
     """
-    Profile().DeleteItem(item)
+    TheProfile.DeleteItem(item)
 
 def Profile_Get(index, fmt=None, default=None):
     """Convenience for Profile().Get()
@@ -270,7 +276,7 @@ def Profile_Get(index, fmt=None, default=None):
     @keyword default: default value to return if not found
 
     """
-    return Profile().Get(index, fmt, default)
+    return TheProfile.Get(index, fmt, default)
 
 def Profile_Set(index, val, fmt=None):
     """Convenience for Profile().Set()
@@ -279,7 +285,7 @@ def Profile_Set(index, val, fmt=None):
     @keyword fmt: format to convert object from
 
     """
-    return Profile().Set(index, val, fmt)
+    return TheProfile.Set(index, val, fmt)
 
 def _FromObject(val, fmt):
     """Convert the given value to a to a profile compatible value
