@@ -19,8 +19,8 @@ LANGUAGE: Python
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: synextreg.py 56840 2008-11-18 19:32:54Z CJP $"
-__revision__ = "$Revision: 56840 $"
+__svnid__ = "$Id: synextreg.py 57169 2008-12-07 16:25:44Z CJP $"
+__revision__ = "$Revision: 57169 $"
 
 #-----------------------------------------------------------------------------#
 import os
@@ -221,6 +221,8 @@ ID_LANG_SQL = _NewId()
 LANG_SQL = u'SQL'
 ID_LANG_PLSQL = _NewId()
 LANG_PLSQL = u'PL/SQL'
+ID_LANG_4GL = _NewId()
+LANG_4GL = u"Progress 4GL"
 
 # Use LEX_TCL
 ID_LANG_TCL  = _NewId()
@@ -271,6 +273,8 @@ LANG_YAML = u'YAML'
 # Use LEX_CONTAINER
 ID_LANG_DJANGO = _NewId()
 LANG_DJANGO = u'Django'
+ID_LANG_ISSL = _NewId()
+LANG_ISSL = u'IssueList'
 ID_LANG_MAKO = _NewId()
 LANG_MAKO = u'Mako'
 ID_LANG_R = _NewId()
@@ -282,6 +286,7 @@ LANG_S = u'S'
 
 # Default extensions to file type mapping
 EXT_MAP = {
+           '4gl'                : LANG_4GL,
            '68k'                : LANG_68K,
            'ada adb ads a'      : LANG_ADA,
            'conf htaccess'      : LANG_APACHE,
@@ -312,6 +317,7 @@ EXT_MAP = {
            'hs'                 : LANG_HASKELL,
            'hx hxml'            : LANG_HAXE,
            'htm html shtm shtml xhtml' : LANG_HTML,
+           'isl'                : LANG_ISSL,
            'iss'                : LANG_INNO,
            'java'               : LANG_JAVA,
            'js'                 : LANG_JS,
