@@ -12,8 +12,8 @@ This file contains various helper functions and utilities that the program uses.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: util.py 57222 2008-12-09 20:01:37Z CJP $"
-__revision__ = "$Revision: 57222 $"
+__svnid__ = "$Id: util.py 57411 2008-12-18 01:54:31Z CJP $"
+__revision__ = "$Revision: 57411 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -142,17 +142,7 @@ class DropTargetFT(wx.PyDropTarget):
         stc = self.window
         if self._tmp is None:
             val = stc.DoDragOver(x_cord, y_cord, drag_result)
-            cline = stc.PositionFromPoint(wx.Point(x_cord, y_cord))
-            if cline != wx.stc.STC_INVALID_POSITION:
-                cline = stc.LineFromPosition(cline)
-                fline = stc.GetFirstVisibleLine()
-                lline = stc.GetLastVisibleLine()
-                if (cline - fline) < 3:
-                    stc.ScrollLines(-2)
-                elif lline - cline < 3:
-                    stc.ScrollLines(2)
-                else:
-                    pass
+            self.ScrollBuffer(stc, x_cord, y_cord)
             return drag_result
         else:
             point = wx.Point(x_cord, y_cord)
@@ -163,6 +153,7 @@ class DropTargetFT(wx.PyDropTarget):
             self._tmp.Show()
             self._tmp.RedrawImage(self._lastp, point, True, True)
             self._lastp = point
+            self.ScrollBuffer(stc, x_cord, y_cord)
         return drag_result
 
     def OnData(self, x_cord, y_cord, drag_result):
@@ -209,6 +200,28 @@ class DropTargetFT(wx.PyDropTarget):
             except wx.PyAssertionError, msg:
                 Log("[droptargetft][err] %s" % str(msg))
 
+    @staticmethod
+    def ScrollBuffer(stc, x_cord, y_cord):
+        """Scroll the buffer as the dragged text is moved towards the
+        ends.
+        @param stc: StyledTextCtrl
+        @param x_cord: int (x position)
+        @param y_cord: int (y position)
+        @note: currenly does not work on wxMac
+
+        """
+        cline = stc.PositionFromPoint(wx.Point(x_cord, y_cord))
+        if cline != wx.stc.STC_INVALID_POSITION:
+            cline = stc.LineFromPosition(cline)
+            fline = stc.GetFirstVisibleLine()
+            lline = stc.GetLastVisibleLine()
+            if (cline - fline) < 2:
+                stc.ScrollLines(-1)
+            elif lline - cline < 2:
+                stc.ScrollLines(1)
+            else:
+                pass
+
 #---- End FileDropTarget ----#
 
 #---- Misc Common Function Library ----#
@@ -520,7 +533,7 @@ def CreateConfigDir():
 
     profile_dir = os.path.join(config_dir, u"profiles")
     dest_file = os.path.join(profile_dir, u"default.ppb")
-    ext_cfg = ["cache", "styles", "plugins"]
+    ext_cfg = [u"cache", u"styles", u"plugins"]
 
     #---- Create Directories ----#
     if not os.path.exists(config_dir):
@@ -567,17 +580,20 @@ def ResolvConfigDir(config_dir, sys_only=False):
     # The following lines are used only when Editra is being run as a
     # source package. If the found path does not exist then Editra is
     # running as as a built package.
-    path = __file__
-    path = os.sep.join(path.split(os.sep)[:-2])
-    path =  path + os.sep + config_dir + os.sep
-    if os.path.exists(path):
-        if not isinstance(path, types.UnicodeType):
-            path = unicode(path, sys.getfilesystemencoding())
-        return path
+    if not hasattr(sys, 'frozen'):
+        path = __file__
+        path = os.sep.join(path.split(os.sep)[:-2])
+        path =  path + os.sep + config_dir + os.sep
+        if os.path.exists(path):
+            if not isinstance(path, types.UnicodeType):
+                path = unicode(path, sys.getfilesystemencoding())
+            return path
 
     # If we get here we need to do some platform dependant lookup
     # to find everything.
     path = sys.argv[0]
+    if not isinstance(path, types.UnicodeType):
+        path = unicode(path, sys.getfilesystemencoding())
 
     # If it is a link get the real path
     if os.path.islink(path):
@@ -607,7 +623,7 @@ def ResolvConfigDir(config_dir, sys_only=False):
 
         if pro_path.startswith(os.sep):
             pass
-        elif pro_path == "":
+        elif pro_path == u"":
             pro_path = os.getcwd()
             pieces = pro_path.split(os.sep)
             if pieces[-1] not in [ed_glob.PROG_NAME.lower(), ed_glob.PROG_NAME]:
@@ -619,6 +635,7 @@ def ResolvConfigDir(config_dir, sys_only=False):
         pro_path = pro_path + os.sep + config_dir + os.sep
 
     path = os.path.normpath(pro_path) + os.sep
+
     # Make sure path is unicode
     if not isinstance(path, types.UnicodeType):
         path = unicode(path, sys.getdefaultencoding())
